<?php

namespace Drupal\warden\Commands;

use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\warden\Service\WardenManager;
use Drush\Commands\DrushCommands;

/**
 * A Drush commandfile.
 *
 * In addition to this file, you need a drush.services.yml
 * in root of your module, and a composer.json file that provides the name
 * of the services file to use.
 *
 * See these files for an example of injecting Drupal services:
 *   - http://cgit.drupalcode.org/devel/tree/src/Commands/DevelCommands.php
 *   - http://cgit.drupalcode.org/devel/tree/drush.services.yml
 */
class WardenCommands extends DrushCommands {

  /**
   * Image cleanup service.
   *
   * @var \Drupal\warden\Service\WardenManager
   */
  protected $wardenManager;

  /**
   * The module handler service.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * {@inheritdoc}
   */
  public function __construct(WardenManager $wardenManager, ModuleHandlerInterface $module_handler) {
    $this->wardenManager = $wardenManager;
    $this->moduleHandler = $module_handler;

    parent::__construct();
  }

  /**
   * Test the connection to Warden by getting its public key
   *
   *
   * @command warden:check
   * @aliases warden-check
   */
  public function check() {
    try {
      $this->output()->writeln(dt('URL: :url', [':url' => $this->wardenManager->getWardenUrl()]));

      if ($this->wardenManager->hasBasicAuthentication()) {
        $this->output()->writeln(dt('HTTP Username: :username', [':username' => $this->wardenManager->getUsername()]));
        $this->output()->writeln(dt('HTTP Password: :password', [':password' => $this->wardenManager->getPassword()]));
      }

      if ($this->wardenManager->hasCertificatePath()) {
        $this->output()->writeln(dt('Certificate file: :path', [':path' => $this->wardenManager->getCertificatePath()]));
      }

      $key = $this->wardenManager->getPublicKey();

      $this->output()->writeln(dt('Going to check connection to Warden server by retrieving the public key ...'));
      $this->output()->writeln($key);
    }
    catch (\Exception $e) {
      $this->output()->writeln('<error>' . $e->getMessage() . '</error>');
    }
  }

  /**
   * Update Warden with the lastest site data
   *
   *
   * @command warden:update
   * @aliases warden-update
   */
  public function update() {
    $this->output()->writeln(dt('Going to update Warden ...'));

    try {
      $this->wardenManager->updateWarden();
      $this->output()->writeln(dt('<info>... success</info>'));
    }
    catch (\Exception $e) {
      $this->output()->writeln('<error>' . $e->getMessage() . '</error>');
    }
  }

  /**
   * Displays the module data that will be sent to Warden
   *
   *
   * @command warden:show-module-data
   * @aliases warden-show-module-data
   */
  public function showModuleData() {
    $this->moduleHandler->loadInclude('warden', 'inc', 'warden.page');

    $data = $this->wardenManager->generateSiteData();
    $this->output()->writeln(json_encode($data));
  }

}
